# Publishing Guide for Wasend SDK

This guide provides step-by-step instructions for setting up and publishing the Wasend SDK for each supported language.

## Prerequisites

- Node.js and npm installed
- Git repository access
- Projen installed globally (`npm install -g projen`)
- Access to respective package registries (npm, PyPI, Maven Central, NuGet, Go)

## TypeScript/JavaScript (npm)

### Setup
1. Ensure you have npm account and are logged in:
   ```bash
   npm login
   ```

2. Build the package:
   ```bash
   npm run build
   ```

3. Package the JavaScript version:
   ```bash
   npm run package:js
   ```

### Publishing
```bash
cd dist/js
npm publish --access public
```

## Python (PyPI)

### Setup
1. Install required tools:
   ```bash
   pip install twine build
   ```

2. Build the package:
   ```bash
   npm run build
   ```

3. Package the Python version:
   ```bash
   npm run package:python
   ```

### Publishing
1. Navigate to the Python package directory:
   ```bash
   cd dist/python
   ```

2. Build the distribution:
   ```bash
   python -m build
   ```

3. Upload to PyPI:
   ```bash
   twine upload dist/*
   ```

## Java (Maven Central)

### Setup
1. Create a Sonatype account at https://issues.sonatype.org/
2. Generate GPG keys for signing:
   ```bash
   gpg --gen-key
   ```

3. Build the package:
   ```bash
   npm run build
   ```

4. Package the Java version:
   ```bash
   npm run package:java
   ```

### Publishing
1. Configure Maven settings in `~/.m2/settings.xml`:
   ```xml
   <settings>
     <servers>
       <server>
         <id>ossrh</id>
         <username>your-sonatype-username</username>
         <password>your-sonatype-password</password>
       </server>
     </servers>
   </settings>
   ```

2. Deploy to Maven Central:
   ```bash
   cd dist/java
   mvn clean deploy
   ```

## .NET (NuGet)

### Setup
1. Install .NET SDK
2. Create a NuGet account at https://www.nuget.org/

3. Build the package:
   ```bash
   npm run build
   ```

4. Package the .NET version:
   ```bash
   npm run package:dotnet
   ```

### Publishing
1. Get your NuGet API key from https://www.nuget.org/account/apikeys

2. Configure NuGet:
   ```bash
   dotnet nuget add source --name nuget.org https://api.nuget.org/v3/index.json
   ```

3. Publish the package:
   ```bash
   cd dist/dotnet
   dotnet nuget push *.nupkg --api-key YOUR_API_KEY --source https://api.nuget.org/v3/index.json
   ```

## Go

### Setup
1. Install Go (1.16 or later)
2. Set up Go modules:
   ```bash
   go mod init github.com/wasenddev/wasend-sdk-go
   ```

3. Build the package:
   ```bash
   npm run build
   ```

4. Package the Go version:
   ```bash
   npm run package:go
   ```

### Publishing
1. Create a new repository at `github.com/wasenddev/wasend-sdk-go`

2. Push the generated Go package:
   ```bash
   cd dist/go
   git init
   git add .
   git commit -m "Initial release"
   git remote add origin https://github.com/wasenddev/wasend-sdk-go.git
   git push -u origin main
   ```

## Version Management

To bump the version for all packages:

1. Update version in package.json:
   ```bash
   npm version <new-version> --no-git-tag-version
   ```

2. Build and package all versions:
   ```bash
   npm run package-all
   ```

3. Follow the publishing steps for each language above.

## Troubleshooting

### Common Issues

1. **Authentication Errors**
   - Ensure you're logged in to all package registries
   - Check API keys and credentials
   - Verify repository permissions

2. **Build Failures**
   - Clean the project: `npm run clobber`
   - Rebuild: `npm run build`
   - Check for dependency conflicts

3. **Publishing Errors**
   - Verify package names match registry requirements
   - Check for duplicate versions
   - Ensure all required metadata is present

### Support

For additional help:
- Email: admin@wasend.dev
- Documentation: https://docs.wasend.dev
- GitHub Issues: https://github.com/wasenddev/wasend-sdk/issues 