/**
 * Group participant role
 */
export declare enum GroupParticipantRole {
    /**
     * Regular participant
     */
    PARTICIPANT = "participant",
    /**
     * Group admin
     */
    ADMIN = "admin",
    /**
     * Group owner
     */
    OWNER = "owner"
}
/**
 * Group participant information
 */
export interface GroupParticipant {
    /**
     * Participant JID
     */
    readonly jid: string;
    /**
     * Participant phone number
     */
    readonly phoneNumber: string;
    /**
     * Participant LID (if available)
     */
    readonly lid?: string;
    /**
     * Whether the participant is an admin
     */
    readonly isAdmin: boolean;
    /**
     * Whether the participant is a super admin
     */
    readonly isSuperAdmin: boolean;
    /**
     * Participant display name
     */
    readonly displayName?: string;
    /**
     * Error code (if any)
     */
    readonly error?: number;
    /**
     * Add request information (if any)
     */
    readonly addRequest?: any;
}
/**
 * Group status
 */
export declare enum GroupStatus {
    /**
     * Group is active
     */
    ACTIVE = "active",
    /**
     * Group is archived
     */
    ARCHIVED = "archived",
    /**
     * Group is deleted
     */
    DELETED = "deleted"
}
/**
 * Group information
 */
export interface Group {
    /**
     * Group JID
     */
    readonly jid: string;
    /**
     * Owner JID
     */
    readonly ownerJid: string;
    /**
     * Owner phone number
     */
    readonly ownerPn: string;
    /**
     * Group name
     */
    readonly name: string;
    /**
     * When the name was set
     */
    readonly nameSetAt: string;
    /**
     * Who set the name
     */
    readonly nameSetBy: string;
    /**
     * Phone number of who set the name
     */
    readonly nameSetByPn: string;
    /**
     * Group topic/description
     */
    readonly topic: string;
    /**
     * Topic ID
     */
    readonly topicId: string;
    /**
     * When the topic was set
     */
    readonly topicSetAt: string;
    /**
     * Who set the topic
     */
    readonly topicSetBy: string;
    /**
     * Phone number of who set the topic
     */
    readonly topicSetByPn: string;
    /**
     * Whether the topic was deleted
     */
    readonly topicDeleted: boolean;
    /**
     * Whether the group is locked
     */
    readonly isLocked: boolean;
    /**
     * Whether the group is an announcement group
     */
    readonly isAnnounce: boolean;
    /**
     * Announcement version ID
     */
    readonly announceVersionId: string;
    /**
     * Whether the group is ephemeral
     */
    readonly isEphemeral: boolean;
    /**
     * Disappearing messages timer in seconds
     */
    readonly disappearingTimer: number;
    /**
     * Whether the group is incognito
     */
    readonly isIncognito: boolean;
    /**
     * Whether the group is a parent group
     */
    readonly isParent: boolean;
    /**
     * Default membership approval mode
     */
    readonly defaultMembershipApprovalMode: string;
    /**
     * Linked parent group JID
     */
    readonly linkedParentJid: string;
    /**
     * Whether the group is a default subgroup
     */
    readonly isDefaultSubGroup: boolean;
    /**
     * Whether join approval is required
     */
    readonly isJoinApprovalRequired: boolean;
    /**
     * Addressing mode
     */
    readonly addressingMode: string;
    /**
     * When the group was created
     */
    readonly groupCreated: string;
    /**
     * Creator's country code
     */
    readonly creatorCountryCode: string;
    /**
     * Participant version ID
     */
    readonly participantVersionId: string;
    /**
     * Group participants
     */
    readonly participants: GroupParticipant[];
    /**
     * Member add mode
     */
    readonly memberAddMode: string;
}
/**
 * Group settings
 */
export interface GroupSettings {
    /**
     * Whether only admins can edit group info
     */
    readonly infoAdminOnly: boolean;
    /**
     * Whether only admins can send messages
     */
    readonly messagesAdminOnly: boolean;
    /**
     * Whether group is archived
     */
    readonly archived?: boolean;
    /**
     * Whether group is muted
     */
    readonly muted?: boolean;
    /**
     * Whether group is pinned
     */
    readonly pinned?: boolean;
}
/**
 * Create group request participant
 */
export interface CreateGroupParticipant {
    /**
     * Participant ID (phone number with country code)
     * @example "+919545251359"
     */
    readonly id: string;
    /**
     * Whether to make the participant an admin
     * @default false
     */
    readonly isAdmin?: boolean;
}
/**
 * Create group request
 */
export interface CreateGroupRequest {
    /**
     * Group name
     */
    readonly name: string;
    /**
     * Group participants
     */
    readonly participants: CreateGroupParticipant[];
    /**
     * Group description (optional)
     */
    readonly description?: string;
    /**
     * Group picture URL (optional)
     */
    readonly pictureUrl?: string;
    /**
     * Group tags (optional)
     */
    readonly tags?: string[];
}
/**
 * Join group request
 */
export interface JoinGroupRequest {
    /**
     * Group code or invite URL
     * @example "https://chat.whatsapp.com/1234567890abcdef"
     */
    readonly code: string;
}
/**
 * Join group response
 */
export interface JoinGroupResponse {
    /**
     * Group ID
     */
    readonly id: string;
    /**
     * Group name
     */
    readonly name: string;
    /**
     * Group participants count
     */
    readonly participantsCount: number;
    /**
     * Group description
     */
    readonly description?: string;
    /**
     * Group picture URL
     */
    readonly pictureUrl?: string;
}
/**
 * Response for group picture operations
 */
export interface GroupPictureResponse {
    /**
     * The URL of the group picture
     */
    readonly url: string;
    /**
     * The format of the picture (e.g., 'jpeg', 'png')
     */
    readonly format?: string;
    /**
     * The size of the picture in bytes
     */
    readonly size?: number;
    /**
     * The dimensions of the picture
     * @example
     * {
     *   "width": "800",
     *   "height": "600"
     * }
     */
    readonly dimensions?: {
        [key: string]: string;
    };
}
/**
 * Profile picture request
 */
export interface ProfilePictureRequest {
    /**
     * Picture URL
     */
    readonly url: string;
    /**
     * Picture format (optional)
     * @default "jpeg"
     */
    readonly format?: 'jpeg' | 'png' | 'webp';
    /**
     * Whether to crop the picture to a square
     * @default true
     */
    readonly cropToSquare?: boolean;
}
/**
 * Description request
 */
export interface DescriptionRequest {
    /**
     * Group description
     */
    readonly description: string;
}
/**
 * Subject request
 */
export interface SubjectRequest {
    /**
     * Group subject/name
     */
    readonly subject: string;
}
/**
 * Settings security change info
 */
export interface SettingsSecurityChangeInfo {
    /**
     * Whether the setting is enabled
     */
    readonly enabled: boolean;
    /**
     * When the setting was last changed
     */
    readonly changedAt?: string;
    /**
     * Who changed the setting
     */
    readonly changedBy?: string;
}
/**
 * Participants request
 */
export interface ParticipantsRequest {
    /**
     * List of participant IDs
     * @example ["+919545251359", "+919545251360"]
     */
    readonly participants: string[];
    /**
     * Whether to notify participants
     * @default true
     */
    readonly notify?: boolean;
}
/**
 * Get groups query parameters
 */
export interface GetGroupsQueryParams {
    /**
     * Sort by field
     */
    readonly sortBy?: 'id' | 'subject' | 'creation' | 'participantsCount';
    /**
     * Sort order
     */
    readonly sortOrder?: 'desc' | 'asc';
    /**
     * Maximum number of results
     * @default 50
     */
    readonly limit?: number;
    /**
     * Number of results to skip
     * @default 0
     */
    readonly offset?: number;
    /**
     * Fields to exclude from response
     */
    readonly exclude?: ('participants')[];
    /**
     * Filter by status
     */
    readonly status?: GroupStatus;
    /**
     * Search by name or description
     */
    readonly search?: string;
    /**
     * Filter by tags
     */
    readonly tags?: string[];
}
/**
 * Response for count operations
 */
export interface CountResponse {
    /**
     * The total count
     */
    readonly total: number;
    /**
     * Count breakdown by status
     * @example
     * {
     *   "ACTIVE": "10",
     *   "ARCHIVED": "5",
     *   "DELETED": "2"
     * }
     */
    readonly byStatus?: {
        [key: string]: string;
    };
}
