export * from './sessions';
export * from './groups';
export * from './contacts';
export * from './messages';
import { Contact, WANumberExistResult, ProfilePictureResponse as ContactProfilePictureResponse, GetContactsQueryParams, GetContactQueryParams, CheckContactExistsQueryParams, GetProfilePictureQueryParams } from './contacts';
import { Group, GroupParticipant, CreateGroupRequest, JoinGroupRequest, JoinGroupResponse, GroupPictureResponse, ProfilePictureRequest, DescriptionRequest, SubjectRequest, SettingsSecurityChangeInfo, ParticipantsRequest, GetGroupsQueryParams, CountResponse } from './groups';
import { MessageTextRequest, MessageImageRequest, MessageFileRequest, MessageVoiceRequest, MessageVideoRequest, MessageLinkCustomPreviewRequest, SendSeenRequest, WAMessage, ChatRequest, SendRequest } from './messages';
import { Session, SessionCreateRequest, GetAllSessionsResponse, QRCodeResponse } from './sessions';
/**
 * Configuration options for the Wasend SDK
 */
export interface WasendConfig {
    /**
     * The API key for authentication
     */
    readonly apiKey: string;
    /**
     * The base URL for the API (optional)
     * @default https://api.wasend.dev
     */
    readonly baseUrl?: string;
    /**
     * Request timeout in milliseconds
     * @default 30000
     */
    readonly timeout?: number;
}
/**
 * Configuration information (without sensitive data)
 */
export interface WasendConfigInfo {
    /**
     * The base URL for the API
     */
    readonly baseUrl?: string;
    /**
     * Request timeout in milliseconds
     */
    readonly timeout?: number;
}
/**
 * Response from API calls
 */
export interface ApiResponse {
    /**
     * Whether the request was successful
     */
    readonly success: boolean;
    /**
     * The response data (if successful)
     */
    readonly data?: any;
    /**
     * Error message if the request failed
     */
    readonly error?: string;
}
/**
 * Message request structure
 */
export interface MessageRequest {
    /**
     * The recipient of the message
     */
    readonly to: string;
    /**
     * The content of the message
     */
    readonly content: string;
}
/**
 * Message data structure
 */
export interface Message {
    /**
     * Unique identifier for the message
     */
    readonly id: string;
    /**
     * The recipient of the message
     */
    readonly to: string;
    /**
     * The content of the message
     */
    readonly content: string;
    /**
     * Timestamp when the message was sent (ISO string)
     */
    readonly sentAt: string;
    /**
     * Message status
     */
    readonly status: string;
}
/**
 * Account information structure
 */
export interface AccountInfo {
    /**
     * Account ID
     */
    readonly id: string;
    /**
     * Account name
     */
    readonly name: string;
    /**
     * Account plan
     */
    readonly plan: string;
}
/**
 * Main Wasend SDK Client
 *
 * This class provides access to the Wasend API for sending messages,
 * managing contacts, and other messaging operations.
 *
 * @example
 * const client = new WasendClient({
 *   apiKey: 'your-api-key'
 * });
 *
 * const result = await client.sendMessage({
 *   to: '+1234567890',
 *   content: 'Hello, World!'
 * });
 */
export declare class WasendClient {
    private readonly config;
    private readonly httpClient;
    /**
     * Creates a new Wasend client instance
     *
     * @param config - Configuration options for the client
     */
    constructor(config: WasendConfig);
    /**
     * Get the current configuration
     *
     * @returns The configuration object (without sensitive data)
     */
    retrieveConfig(): WasendConfigInfo;
    createSession(request: SessionCreateRequest): Promise<Session>;
    retrieveAllSessions(): Promise<GetAllSessionsResponse>;
    deleteSession(sessionId: string): Promise<void>;
    retrieveSessionInfo(sessionId: string): Promise<Session>;
    startSession(sessionId: string): Promise<Session>;
    stopSession(sessionId: string): Promise<Session>;
    restartSession(sessionId: string): Promise<Session>;
    retrieveQRCode(sessionId: string): Promise<QRCodeResponse>;
    /**
     * Send a message to a recipient
     *
     * @param request - The message to send
     * @returns Promise resolving to the API response
     */
    sendMessage(request: MessageRequest): Promise<ApiResponse>;
    /**
     * Get message by ID
     *
     * @param messageId - The ID of the message to retrieve
     * @returns Promise resolving to the API response
     */
    getMessage(messageId: string): Promise<ApiResponse>;
    /**
     * Get account information
     *
     * @returns Promise resolving to the API response
     */
    retrieveAccount(): Promise<ApiResponse>;
    /**
     * Create a new group
     *
     * @param sessionId - The session ID
     * @param request - The group creation request
     * @returns Promise resolving to the created group
     *
     * @example
     * curl -X POST 'http://localhost:3001/{sessionId}/groups' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "name": "My Group",
     *     "participants": [{"id": "+1234567890"}],
     *     "description": "Group description"
     *   }'
     */
    createGroup(sessionId: string, request: CreateGroupRequest): Promise<Group>;
    /**
     * Get all groups
     *
     * @param sessionId - The session ID
     * @param params - Optional query parameters
     * @returns Promise resolving to the list of groups
     *
     * @example
     * curl -X GET 'http://localhost:3001/{sessionId}/groups?sortBy=creation&sortOrder=desc&limit=50&offset=0' \
     *   -H 'Authorization: Bearer {apiKey}'
     */
    getGroups(sessionId: string, params?: GetGroupsQueryParams): Promise<Group[]>;
    /**
     * Get group join info
     *
     * @param sessionId - The session ID
     * @param code - Group code or invite URL
     * @returns Promise resolving to the group info
     *
     * @example
     * curl -X GET 'http://localhost:3001/{sessionId}/groups/join-info?code=https://chat.whatsapp.com/1234567890abcdef' \
     *   -H 'Authorization: Bearer {apiKey}'
     */
    getGroupJoinInfo(sessionId: string, code: string): Promise<Group>;
    /**
     * Join a group
     *
     * @param sessionId - The session ID
     * @param request - The join group request
     * @returns Promise resolving to the join group response
     *
     * @example
     * curl -X POST 'http://localhost:3001/{sessionId}/groups/join' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "code": "https://chat.whatsapp.com/1234567890abcdef"
     *   }'
     */
    joinGroup(sessionId: string, request: JoinGroupRequest): Promise<JoinGroupResponse>;
    /**
     * Get groups count
     *
     * @param sessionId - The session ID
     * @returns Promise resolving to the count response
     *
     * @example
     * curl -X GET 'http://localhost:3001/{sessionId}/groups/count' \
     *   -H 'Authorization: Bearer {apiKey}'
     */
    getGroupsCount(sessionId: string): Promise<CountResponse>;
    /**
     * Get a specific group
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID
     * @returns Promise resolving to the group
     *
     * @example
     * curl -X GET 'http://localhost:3001/{sessionId}/groups/{groupId}' \
     *   -H 'Authorization: Bearer {apiKey}'
     */
    getGroup(sessionId: string, groupId: string): Promise<Group>;
    /**
     * Leave a group
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID
     *
     * @example
     * curl -X POST 'http://localhost:3001/{sessionId}/groups/{groupId}/leave' \
     *   -H 'Authorization: Bearer {apiKey}'
     */
    leaveGroup(sessionId: string, groupId: string): Promise<void>;
    /**
     * Get group picture
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID
     * @param refresh - Whether to refresh the picture from server
     * @returns Promise resolving to the group picture response
     *
     * @example
     * curl -X GET 'http://localhost:3001/{sessionId}/groups/{groupId}/picture?refresh=true' \
     *   -H 'Authorization: Bearer {apiKey}'
     */
    getGroupPicture(sessionId: string, groupId: string, refresh?: boolean): Promise<GroupPictureResponse>;
    /**
     * Set group picture
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID
     * @param request - The profile picture request
     *
     * @example
     * curl -X PUT 'http://localhost:3001/{sessionId}/groups/{groupId}/picture' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "url": "https://example.com/picture.jpg",
     *     "format": "jpeg",
     *     "cropToSquare": true
     *   }'
     */
    setGroupPicture(sessionId: string, groupId: string, request: ProfilePictureRequest): Promise<void>;
    /**
     * Delete group picture
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID
     *
     * @example
     * curl -X DELETE 'http://localhost:3001/{sessionId}/groups/{groupId}/picture' \
     *   -H 'Authorization: Bearer {apiKey}'
     */
    deleteGroupPicture(sessionId: string, groupId: string): Promise<void>;
    /**
     * Set group description
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID
     * @param request - The description request
     *
     * @example
     * curl -X PUT 'http://localhost:3001/{sessionId}/groups/{groupId}/description' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "description": "New group description"
     *   }'
     */
    setGroupDescription(sessionId: string, groupId: string, request: DescriptionRequest): Promise<void>;
    /**
     * Set group subject
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID
     * @param request - The subject request
     *
     * @example
     * curl -X PUT 'http://localhost:3001/{sessionId}/groups/{groupId}/subject' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "subject": "New group name"
     *   }'
     */
    setGroupSubject(sessionId: string, groupId: string, request: SubjectRequest): Promise<void>;
    /**
     * Set group info admin only setting
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID
     * @param request - The settings security change info
     *
     * @example
     * curl -X PUT 'http://localhost:3001/{sessionId}/groups/{groupId}/settings/security/info-admin-only' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "enabled": true
     *   }'
     */
    setGroupInfoAdminOnly(sessionId: string, groupId: string, request: SettingsSecurityChangeInfo): Promise<void>;
    /**
     * Get group info admin only setting
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID
     * @returns Promise resolving to the settings security change info
     *
     * @example
     * curl -X GET 'http://localhost:3001/{sessionId}/groups/{groupId}/settings/security/info-admin-only' \
     *   -H 'Authorization: Bearer {apiKey}'
     */
    getGroupInfoAdminOnly(sessionId: string, groupId: string): Promise<SettingsSecurityChangeInfo>;
    /**
     * Set group messages admin only setting
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID
     * @param request - The settings security change info
     *
     * @example
     * curl -X PUT 'http://localhost:3001/{sessionId}/groups/{groupId}/settings/security/messages-admin-only' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "enabled": true
     *   }'
     */
    setGroupMessagesAdminOnly(sessionId: string, groupId: string, request: SettingsSecurityChangeInfo): Promise<void>;
    /**
     * Get group messages admin only setting
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID
     * @returns Promise resolving to the settings security change info
     *
     * @example
     * curl -X GET 'http://localhost:3001/{sessionId}/groups/{groupId}/settings/security/messages-admin-only' \
     *   -H 'Authorization: Bearer {apiKey}'
     */
    getGroupMessagesAdminOnly(sessionId: string, groupId: string): Promise<SettingsSecurityChangeInfo>;
    /**
     * Get group invite code
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID
     * @returns Promise resolving to the invite code
     *
     * @example
     * curl -X GET 'http://localhost:3001/{sessionId}/groups/{groupId}/invite-code' \
     *   -H 'Authorization: Bearer {apiKey}'
     */
    getGroupInviteCode(sessionId: string, groupId: string): Promise<string>;
    /**
     * Revoke group invite code
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID
     * @returns Promise resolving to the new invite code
     *
     * @example
     * curl -X POST 'http://localhost:3001/{sessionId}/groups/{groupId}/invite-code/revoke' \
     *   -H 'Authorization: Bearer {apiKey}'
     */
    revokeGroupInviteCode(sessionId: string, groupId: string): Promise<string>;
    /**
     * Get group participants
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID
     * @returns Promise resolving to the list of participants
     *
     * @example
     * curl -X GET 'http://localhost:3001/{sessionId}/groups/{groupId}/participants' \
     *   -H 'Authorization: Bearer {apiKey}'
     */
    getGroupParticipants(sessionId: string, groupId: string): Promise<GroupParticipant[]>;
    /**
     * Add participants to group
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID (full JID, e.g., 1234567890-12345678@g.us)
     * @param request - The participants request. Participant IDs should be phone numbers (e.g., +1234567890) or full JIDs.
     *
     * @example
     * curl -X POST 'http://localhost:3001/{sessionId}/groups/{groupId}/participants/add' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "participants": ["+1234567890", "+0987654321"],
     *     "notify": true
     *   }'
     */
    addGroupParticipants(sessionId: string, groupId: string, request: ParticipantsRequest): Promise<void>;
    /**
     * Remove participants from group
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID (full JID, e.g., 1234567890-12345678@g.us)
     * @param request - The participants request. Participant IDs should be phone numbers (e.g., +1234567890) or full JIDs.
     *
     * @example
     * curl -X POST 'http://localhost:3001/{sessionId}/groups/{groupId}/participants/remove' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "participants": ["+1234567890", "+0987654321"],
     *     "notify": true
     *   }'
     */
    removeGroupParticipants(sessionId: string, groupId: string, request: ParticipantsRequest): Promise<void>;
    /**
     * Promote participants to admin
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID (full JID, e.g., 1234567890-12345678@g.us)
     * @param request - The participants request. Participant IDs should be phone numbers (e.g., +1234567890) or full JIDs.
     *
     * @example
     * curl -X POST 'http://localhost:3001/{sessionId}/groups/{groupId}/admin/promote' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "participants": ["+1234567890", "+0987654321"],
     *     "notify": true
     *   }'
     */
    promoteGroupParticipants(sessionId: string, groupId: string, request: ParticipantsRequest): Promise<void>;
    /**
     * Demote participants from admin
     *
     * @param sessionId - The session ID
     * @param groupId - The group ID (full JID, e.g., 1234567890-12345678@g.us)
     * @param request - The participants request. Participant IDs should be phone numbers (e.g., +1234567890) or full JIDs.
     *
     * @example
     * curl -X POST 'http://localhost:3001/{sessionId}/groups/{groupId}/admin/demote' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "participants": ["+1234567890", "+0987654321"],
     *     "notify": true
     *   }'
     */
    demoteGroupParticipants(sessionId: string, groupId: string, request: ParticipantsRequest): Promise<void>;
    /**
     * Get all contacts
     *
     * @param sessionId - The session ID
     * @param params - Optional query parameters
     * @returns Promise resolving to the list of contacts
     *
     * @example
     * curl -X GET 'http://localhost:3001/contacts/all?session={sessionId}&sortBy=name&sortOrder=asc&limit=10&offset=0' \
     *   -H 'Authorization: Bearer {apiKey}'
     */
    getContacts(sessionId: string, params?: GetContactsQueryParams): Promise<Contact[]>;
    /**
     * Get contact basic info
     *
     * @param sessionId - The session ID
     * @param params - The contact query parameters. Use a phone number for 'contactId' (e.g., +1234567890) or a full JID.
     * @returns Promise resolving to the contact information
     *
     * @example
     * curl -X GET 'http://localhost:3001/contacts?session={sessionId}&contactId=+11111111111' \
     *   -H 'Authorization: Bearer {apiKey}'
     */
    getContact(sessionId: string, params: GetContactQueryParams): Promise<Contact>;
    /**
     * Check if a phone number is registered in WhatsApp
     *
     * @param sessionId - The session ID
     * @param params - The check exists query parameters. 'phone' should be a number without '+' (e.g., 1213213213).
     * @returns Promise resolving to the check result
     *
     * @example
     * curl -X GET 'http://localhost:3001/contacts/check-exists?session={sessionId}&phone=1213213213' \
     *   -H 'Authorization: Bearer {apiKey}'
     */
    checkContactExists(sessionId: string, params: CheckContactExistsQueryParams): Promise<WANumberExistResult>;
    /**
     * Get contact's profile picture URL
     *
     * @param sessionId - The session ID
     * @param params - The profile picture query parameters. Use a phone number for 'contactId' (e.g., +1234567890) or a full JID.
     * @returns Promise resolving to the profile picture response
     *
     * @example
     * curl -X GET 'http://localhost:3001/contacts/profile-picture?session={sessionId}&contactId=+11111111111&refresh=false' \
     *   -H 'Authorization: Bearer {apiKey}'
     */
    getContactProfilePicture(sessionId: string, params: GetProfilePictureQueryParams): Promise<ContactProfilePictureResponse>;
    /**
     * Send a text message
     *
     * @param request - The text message request. For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.
     * @returns Promise resolving to the sent message
     *
     * @example
     * curl -X POST 'http://localhost:3001/sendText' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "session": "sessionId",
     *     "to": "+11111111111",
     *     "text": "Hello, World!"
     *   }'
     */
    sendText(request: MessageTextRequest): Promise<WAMessage>;
    /**
     * Send an image message
     *
     * @param request - The image message request. For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.
     * @returns Promise resolving to the sent message
     *
     * @example
     * curl -X POST 'http://localhost:3001/sendImage' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "session": "sessionId",
     *     "to": "+11111111111",
     *     "url": "https://example.com/image.jpg",
     *     "caption": "Check out this image!"
     *   }'
     */
    sendImage(request: MessageImageRequest): Promise<WAMessage>;
    /**
     * Send a file message
     *
     * @param request - The file message request. For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.
     * @returns Promise resolving to the sent message
     *
     * @example
     * curl -X POST 'http://localhost:3001/sendFile' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "session": "sessionId",
     *     "to": "+11111111111",
     *     "url": "https://example.com/file.pdf",
     *     "fileName": "document.pdf",
     *     "mimeType": "application/pdf"
     *   }'
     */
    sendFile(request: MessageFileRequest): Promise<WAMessage>;
    /**
     * Send a voice message
     *
     * @param request - The voice message request. For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.
     * @returns Promise resolving to the sent message
     *
     * @example
     * curl -X POST 'http://localhost:3001/sendVoice' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "session": "sessionId",
     *     "to": "+11111111111",
     *     "url": "https://example.com/voice.mp3",
     *     "duration": 30
     *   }'
     */
    sendVoice(request: MessageVoiceRequest): Promise<WAMessage>;
    /**
     * Send a video message
     *
     * @param request - The video message request. For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.
     * @returns Promise resolving to the sent message
     *
     * @example
     * curl -X POST 'http://localhost:3001/sendVideo' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "session": "sessionId",
     *     "to": "+11111111111",
     *     "url": "https://example.com/video.mp4",
     *     "caption": "Check out this video!"
     *   }'
     */
    sendVideo(request: MessageVideoRequest): Promise<WAMessage>;
    /**
     * Send a text message with custom link preview
     *
     * @param request - The message with custom link preview request. For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.
     * @returns Promise resolving to the sent message
     *
     * @example
     * curl -X POST 'http://localhost:3001/send/link-custom-preview' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "session": "sessionId",
     *     "to": "+11111111111",
     *     "text": "Check out this link!",
     *     "preview": {
     *       "title": "Example Website",
     *       "description": "A great website",
     *       "thumbnailUrl": "https://example.com/thumbnail.jpg"
     *     }
     *   }'
     */
    sendLinkCustomPreview(request: MessageLinkCustomPreviewRequest): Promise<WAMessage>;
    /**
     * Mark a message as seen
     *
     * @param request - The send seen request. For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.
     *
     * @example
     * curl -X POST 'http://localhost:3001/sendSeen' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "session": "sessionId",
     *     "to": "+11111111111",
     *     "messageId": "messageId"
     *   }'
     */
    sendSeen(request: SendSeenRequest): Promise<void>;
    /**
     * Start typing indicator
     *
     * @param request - The chat request. For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.
     *
     * @example
     * curl -X POST 'http://localhost:3001/startTyping' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "session": "sessionId",
     *     "to": "+11111111111"
     *   }'
     */
    startTyping(request: ChatRequest): Promise<void>;
    /**
     * Stop typing indicator
     *
     * @param request - The chat request. For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.
     *
     * @example
     * curl -X POST 'http://localhost:3001/stopTyping' \
     *   -H 'Authorization: Bearer {apiKey}' \
     *   -H 'Content-Type: application/json' \
     *   -d '{
     *     "session": "sessionId",
     *     "to": "+11111111111"
     *   }'
     */
    stopTyping(request: ChatRequest): Promise<void>;
    /**
     * Send a message using the unified send endpoint
     *
     * @param request - The send request. For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.
     * @returns Promise resolving to the sent message
     *
     * @example
     * // Send a text message
     * const textMessage = await client.send({
     *   session: "sessionId",
     *   to: "+1234567890",
     *   text: "Hello from WASend!"
     * });
     *
     * // Send an image
     * const imageMessage = await client.send({
     *   session: "sessionId",
     *   to: "+1234567890",
     *   imageUrl: "https://example.com/image.jpg",
     *   text: "Check out this image!",
     *   mimetype: "image/jpeg"
     * });
     *
     * // Send a video
     * const videoMessage = await client.send({
     *   session: "sessionId",
     *   to: "+1234567890",
     *   videoUrl: "https://example.com/video.mp4",
     *   text: "Check out this video!",
     *   mimetype: "video/mp4"
     * });
     *
     * // Send a document
     * const documentMessage = await client.send({
     *   session: "sessionId",
     *   to: "+1234567890",
     *   documentUrl: "https://example.com/document.pdf",
     *   filename: "document.pdf",
     *   mimetype: "application/pdf"
     * });
     *
     * // Send an audio message
     * const audioMessage = await client.send({
     *   session: "sessionId",
     *   to: "+1234567890",
     *   audioUrl: "https://example.com/audio.mp3",
     *   mimetype: "audio/mpeg"
     * });
     */
    send(request: SendRequest): Promise<WAMessage>;
    /**
     * Utility method to process a message with proper timing and typing indicators
     * This follows WhatsApp's guidelines to avoid being flagged as spam
     *
     * @param request - The send request to process. For 'to', use recipient's phone number (e.g., +1234567890) or a full group JID.
     * @param options - Optional configuration for the message processing
     * @returns Promise resolving to the sent message
     *
     * @example
     * // Send a text message with proper processing
     * const message = await client.processMessage({
     *   session: "sessionId",
     *   to: "+1234567890",
     *   text: "Hello, World!"
     * });
     *
     * // Send an image with caption and proper processing
     * const imageMessage = await client.processMessage({
     *   session: "sessionId",
     *   to: "+1234567890",
     *   imageUrl: "https://example.com/image.jpg",
     *   text: "Check out this image!"
     * });
     */
    processMessage(request: SendRequest, options?: Record<string, string>): Promise<WAMessage>;
}
/**
 * Utility functions for the Wasend SDK
 */
export declare class WasendUtils {
    /**
     * Check if a phone number is valid
     *
     * @param phoneNumber - The phone number to validate
     * @returns Whether the phone number is valid
     */
    static isValidPhoneNumber(phoneNumber: string): boolean;
    /**
     * Format a phone number to international format
     *
     * @param phoneNumber - The phone number to format
     * @param countryCode - Optional country code to use
     * @returns Formatted phone number
     */
    static formatPhoneNumber(phoneNumber: string, countryCode?: string): string;
}
