/**
 * Base chat request interface
 */
export interface ChatRequest {
    /**
     * The session ID
     */
    readonly session: string;
    /**
     * The recipient's phone number or group JID
     * @example "+1234567890" or "1234567890-12345678@g.us"
     */
    readonly to: string;
}
/**
 * Base message request interface
 */
export interface MessageRequest extends ChatRequest {
    /**
     * Whether to send the message as a reply to a specific message
     */
    readonly replyTo?: string;
}
/**
 * Text message request
 */
export interface MessageTextRequest extends MessageRequest {
    /**
     * The text content of the message
     */
    readonly text: string;
}
/**
 * Image message request
 */
export interface MessageImageRequest extends MessageRequest {
    /**
     * The image URL
     */
    readonly url?: string;
    /**
     * The image data in base64 format
     */
    readonly data?: string;
    /**
     * The image caption
     */
    readonly caption?: string;
}
/**
 * File message request
 */
export interface MessageFileRequest extends MessageRequest {
    /**
     * The file URL
     */
    readonly url?: string;
    /**
     * The file data in base64 format
     */
    readonly data?: string;
    /**
     * The file name
     */
    readonly fileName: string;
    /**
     * The file mime type
     */
    readonly mimeType: string;
}
/**
 * Voice message request
 */
export interface MessageVoiceRequest extends MessageRequest {
    /**
     * The voice message URL
     */
    readonly url?: string;
    /**
     * The voice message data in base64 format
     */
    readonly data?: string;
    /**
     * The voice message duration in seconds
     */
    readonly duration?: number;
}
/**
 * Video message request
 */
export interface MessageVideoRequest extends MessageRequest {
    /**
     * The video URL
     */
    readonly url?: string;
    /**
     * The video data in base64 format
     */
    readonly data?: string;
    /**
     * The video caption
     */
    readonly caption?: string;
}
/**
 * Link preview request
 */
export interface LinkPreviewRequest {
    /**
     * The link title
     */
    readonly title: string;
    /**
     * The link description
     */
    readonly description?: string;
    /**
     * The link thumbnail URL
     */
    readonly thumbnailUrl?: string;
}
/**
 * Message with custom link preview request
 */
export interface MessageLinkCustomPreviewRequest extends MessageTextRequest {
    /**
     * The link preview information
     */
    readonly preview: LinkPreviewRequest;
}
/**
 * Send seen request
 */
export interface SendSeenRequest extends ChatRequest {
    /**
     * The message ID to mark as seen
     */
    readonly messageId: string;
}
/**
 * WhatsApp message response
 */
export interface WAMessage {
    /**
     * The message ID
     */
    readonly id: string;
    /**
     * The recipient's phone number or group JID
     */
    readonly to: string;
    /**
     * The message content
     */
    readonly content: string;
    /**
     * The message type
     */
    readonly type: string;
    /**
     * The message timestamp
     */
    readonly timestamp: string;
    /**
     * The message status
     */
    readonly status: string;
    /**
     * Whether the message is from me
     */
    readonly fromMe: boolean;
    /**
     * The message sender
     */
    readonly sender: string;
    /**
     * The message recipient
     */
    readonly recipient: string;
}
/**
 * Send message request interface
 */
export interface SendRequest {
    /**
     * The session ID
     */
    readonly session: string;
    /**
     * The recipient's phone number or group JID
     * @example "+1234567890" or "1234567890-12345678@g.us"
     */
    readonly to: string;
    /**
     * The message text or caption
     * @example "Hello from WASend!"
     */
    readonly text?: string;
    /**
     * The image URL
     * @example "https://example.com/image.jpg"
     */
    readonly imageUrl?: string;
    /**
     * The video URL
     * @example "https://example.com/video.mp4"
     */
    readonly videoUrl?: string;
    /**
     * The document URL
     * @example "https://example.com/document.pdf"
     */
    readonly documentUrl?: string;
    /**
     * The audio URL
     * @example "https://example.com/audio.mp3"
     */
    readonly audioUrl?: string;
    /**
     * The MIME type of the media
     * @example "image/jpeg"
     */
    readonly mimetype?: string;
    /**
     * The filename for the media
     * @example "custom_image.jpg"
     */
    readonly filename?: string;
    /**
     * The link preview information
     */
    readonly preview?: Record<string, string>;
}
