export interface SessionMetadata {
    readonly userId: string;
    readonly userEmail: string;
}
export interface NowebStoreConfig {
    readonly enabled: boolean;
    readonly fullSync: boolean;
}
export interface NowebConfig {
    readonly markOnline: boolean;
    readonly store: NowebStoreConfig;
}
export interface GrpcStatus {
    readonly client: string;
    readonly stream: string;
}
export interface GowsStatus {
    readonly found: boolean;
    readonly connected: boolean;
}
/**
 * Session creation request body
 */
export interface SessionCreateRequest {
    /**
     * Name of the session
     */
    readonly sessionName: string;
    /**
     * Phone number for the WhatsApp session
     */
    readonly phoneNumber: string;
    /**
     * Enable account protection features
     * @default false
     */
    readonly enableAccountProtection?: boolean;
    /**
     * Enable message logging
     * @default false
     */
    readonly enableMessageLogging?: boolean;
    /**
     * Enable webhook notifications
     * @default false
     */
    readonly enableWebhook?: boolean;
    /**
     * Webhook URL for notifications
     * Required if enableWebhook is true
     */
    readonly webhookUrl?: string;
}
/**
 * Session configuration
 */
export interface SessionConfig {
    /**
     * User metadata
     */
    readonly metadata: SessionMetadata;
    /**
     * Proxy configuration
     */
    readonly proxy: any;
    /**
     * Debug mode
     */
    readonly debug: boolean;
    /**
     * Noweb configuration
     */
    readonly noweb: NowebConfig;
    /**
     * Webhook configurations
     */
    readonly webhooks: any[];
}
/**
 * Engine status information
 */
export interface EngineStatus {
    /**
     * gRPC status
     */
    readonly grpc: GrpcStatus;
    /**
     * GoWS status
     */
    readonly gows: GowsStatus;
}
/**
 * Session details
 */
export interface SessionDetails {
    /**
     * MongoDB ID of the session
     */
    readonly id: string;
    /**
     * Unique session identifier
     */
    readonly uniqueSessionId: string;
    /**
     * User ID who owns the session
     */
    readonly userId: string;
    /**
     * Name of the session
     */
    readonly sessionName: string;
    /**
     * Phone number associated with the session
     */
    readonly phoneNumber: string;
    /**
     * Session configuration flags
     */
    readonly enableAccountProtection: boolean;
    readonly enableMessageLogging: boolean;
    readonly enableWebhook: boolean;
    readonly webhookUrl?: string;
    /**
     * Creation timestamp
     */
    readonly createdAt: string;
    /**
     * Last update timestamp
     */
    readonly updatedAt: string;
}
/**
 * Downstream connection information
 */
export interface DownstreamInfo {
    /**
     * Name of the downstream connection
     */
    readonly name: string;
    /**
     * Status of the downstream connection
     */
    readonly status: string;
    /**
     * Configuration for the downstream connection
     */
    readonly config: SessionConfig;
    /**
     * Engine status information
     */
    readonly engine: EngineStatus;
}
/**
 * Session information from getAllSessions
 */
export interface SessionListItem {
    /**
     * Session details
     */
    readonly session: SessionDetails;
    /**
     * Downstream connection information
     */
    readonly downstream: DownstreamInfo;
}
/**
 * Response wrapper for getAllSessions
 */
export interface GetAllSessionsResponse {
    /**
     * Array of sessions
     */
    readonly sessions: SessionListItem[];
}
/**
 * Session information from createSession and other operations
 */
export interface Session extends SessionDetails {
    /**
     * Name of the session
     */
    readonly name: string;
    /**
     * Current status of the session
     */
    readonly status: string;
    /**
     * Session configuration
     */
    readonly config: SessionConfig;
    /**
     * Engine status information
     */
    readonly engine: EngineStatus;
}
/**
 * QR code response
 */
export interface QRCodeResponse {
    /**
     * QR code data
     */
    readonly data: string;
}
